aboutsummaryrefslogtreecommitdiffstats
path: root/target/linux/ar71xx/patches-3.10/712-MIPS-ath79-add-EasyLink-support.patch
diff options
context:
space:
mode:
Diffstat (limited to 'target/linux/ar71xx/patches-3.10/712-MIPS-ath79-add-EasyLink-support.patch')
-rw-r--r--target/linux/ar71xx/patches-3.10/712-MIPS-ath79-add-EasyLink-support.patch15
1 files changed, 7 insertions, 8 deletions
diff --git a/target/linux/ar71xx/patches-3.10/712-MIPS-ath79-add-EasyLink-support.patch b/target/linux/ar71xx/patches-3.10/712-MIPS-ath79-add-EasyLink-support.patch
index bf7eed9416..f697a1db49 100644
--- a/target/linux/ar71xx/patches-3.10/712-MIPS-ath79-add-EasyLink-support.patch
+++ b/target/linux/ar71xx/patches-3.10/712-MIPS-ath79-add-EasyLink-support.patch
@@ -1,21 +1,20 @@
--- a/arch/mips/ath79/Kconfig
+++ b/arch/mips/ath79/Kconfig
@@ -337,6 +337,26 @@ config ATH79_MACH_EW_DORIN
Say 'Y' here if you want your kernel to support the
Dorin Platform from www.80211.de .
-
+
+config ATH79_MACH_EL_M150
+ bool "EasyLink EL-M150 support"
+ select SOC_AR933X
--- a/arch/mips/ath79/machtypes.h
+++ b/arch/mips/ath79/machtypes.h
-@@ -50,7 +50,9 @@ enum ath79_mach_type {
+@@ -50,6 +50,8 @@ enum ath79_mach_type {
ATH79_MACH_EW_DORIN, /* embedded wireless Dorin Platform */
- ATH79_MACH_EW_DORIN_ROUTER, /* embedded wireless Dorin Router Platform */
- ATH79_MACH_EAP7660D, /* Senao EAP7660D */
+ ATH79_MACH_EW_DORIN_ROUTER, /* embedded wireless Dorin Router Platform */
+ ATH79_MACH_EAP7660D, /* Senao EAP7660D */
+ ATH79_MACH_EL_M150, /* EasyLink EL-M150 */
+ ATH79_MACH_EL_MINI, /* EasyLink EL-MINI */
- ATH79_MACH_GS_OOLITE, /* GS OOLITE V1.0 */
- ATH79_MACH_HIWIFI_HC6361, /* HiWiFi HC6361 */
- ATH79_MACH_JA76PF, /* jjPlus JA76PF */
- ATH79_MACH_JA76PF2, /* jjPlus JA76PF2 */
+ ATH79_MACH_GS_OOLITE, /* GS OOLITE V1.0 */
+ ATH79_MACH_HIWIFI_HC6361, /* HiWiFi HC6361 */
+ ATH79_MACH_JA76PF, /* jjPlus JA76PF */